/**
 * Check if SDP has a media section (audio or video)
 */
export declare const sdpHasMediaSection: (sdp: string, media: "audio" | "video") => boolean;
/**
 * Check if SDP includes video
 */
export declare const sdpHasVideo: (sdp: string) => boolean;
/**
 * Check if SDP includes audio
 */
export declare const sdpHasAudio: (sdp: string) => boolean;
/**
 * Add stereo support hacking the SDP
 * @return the SDP modified
 */
export declare const sdpStereoHack: (sdp: string) => string;
export declare const sdpMediaOrderHack: (answer: string, localOffer: string) => string;
/**
 * Modify the SDP to increase video bitrate
 * @return the SDP modified
 */
export declare const sdpBitrateHack: (sdp: string, max: number, min: number, start: number) => string;
/**
 * Check for srflx, prflx or relay candidates
 * TODO: improve the logic check private/public IP for typ host
 *
 * @param sdp string
 * @returns boolean
 */
export declare const sdpHasValidCandidates: (sdp: string) => boolean;
/**
 * Remove "a=candidate" lines with local candidates
 * https://bloggeek.me/psa-mdns-and-local-ice-candidates-are-coming/
 */
export declare const sdpRemoveLocalCandidates: (sdp: string) => string;
/**
 * Get the SDP direction for the specified media type.
 * Returns 'sendrecv' if no direction attribute is found, as per SDP standards.
 */
export declare const getSdpDirection: (sdp: string, media: "audio" | "video") => RTCRtpTransceiverDirection;
/**
 * Returns the opposite SDP direction based on the provided direction.
 */
export declare const getOppositeSdpDirection: (direction: RTCRtpTransceiverDirection) => RTCRtpTransceiverDirection;
/**
 * Returns boolean indicating remote and local SDPs has the expected opposite direction
 */
export declare const hasMatchingSdpDirection: ({ localSdp, remoteSdp, media, }: {
    localSdp: string;
    remoteSdp: string;
    media: "audio" | "video";
}) => boolean;
//# sourceMappingURL=sdpHelpers.d.ts.map